@@ -58,14 +58,17 @@ class Paragraph(object):
         super(Paragraph, self).__init__()
         self._p = p
 
-    def add_run(self, text=None):
+    def add_run(self, text=None, style=None):
         """
-        Append a run to this paragraph.
+        Append a run to this paragraph containing *text* and having character
+        style identified by style ID *style*.
         """
         r = self._p.add_r()
         run = Run(r)
         if text:
             run.add_text(text)
+        if style:
+            run.style = style
         return run
 
     @property
@@ -300,6 +303,21 @@ class Run(object):
         """
         return 'strike'
 
+    @property
+    def style(self):
+        """
+        Read/write. The string style ID of the character style applied to
+        this run, or |None| if it has no directly-applied character style.
+        Setting this property to |None| causes any directly-applied character
+        style to be removed such that the run inherits character formatting
+        from its containing paragraph.
+        """
+        return self._r.style
+
+    @style.setter
+    def style(self, char_style):
+        self._r.style = char_style
+
     @property
     def text(self):
         """
