@@ -20,7 +20,7 @@ from .oxml.unitdata.text import (
     a_b, a_bCs, a_br, a_caps, a_cs, a_dstrike, a_p, a_shadow, a_smallCaps,
     a_snapToGrid, a_specVanish, a_strike, a_t, a_vanish, a_webHidden,
     an_emboss, an_i, an_iCs, an_imprint, an_oMath, a_noProof, an_outline,
-    an_r, an_rPr, an_rtl
+    an_r, an_rPr, an_rStyle, an_rtl
 )
 from .unitutil import class_mock, instance_mock
 
@@ -34,8 +34,8 @@ class DescribeParagraph(object):
         assert runs == [run_, run_2_]
 
     def it_can_add_a_run_to_itself(self, add_run_fixture):
-        paragraph, text, expected_xml = add_run_fixture
-        run = paragraph.add_run(text)
+        paragraph, text, style, expected_xml = add_run_fixture
+        run = paragraph.add_run(text, style)
         assert paragraph._p.xml == expected_xml
         assert isinstance(run, Run)
         assert run._r is paragraph._p.r_lst[0]
@@ -66,21 +66,29 @@ class DescribeParagraph(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[None, '', 'foobar'])
+    @pytest.fixture(params=[
+        (None, None), (None, 'Strong'), ('foobar', None), ('foobar', 'Strong')
+    ])
     def add_run_fixture(self, request, paragraph):
-        text = request.param
+        text, style = request.param
         r_bldr = an_r()
+        if style:
+            r_bldr.with_child(
+                an_rPr().with_child(an_rStyle().with_val(style))
+            )
         if text:
             r_bldr.with_child(a_t().with_text(text))
         expected_xml = a_p().with_nsdecls().with_child(r_bldr).xml()
-        return paragraph, text, expected_xml
+        return paragraph, text, style, expected_xml
+
+    # fixture components ---------------------------------------------
 
     @pytest.fixture
     def p_(self, request, r_, r_2_):
         return instance_mock(request, CT_P, r_lst=(r_, r_2_))
 
     @pytest.fixture
-    def paragraph(self, request):
+    def paragraph(self):
         p = a_p().with_nsdecls().element
         return Paragraph(p)
 
@@ -135,6 +143,15 @@ class DescribeRun(object):
         setattr(run, prop_name, value)
         assert run._r.xml == expected_xml
 
+    def it_knows_its_character_style(self, style_get_fixture):
+        run, expected_style = style_get_fixture
+        assert run.style == expected_style
+
+    def it_can_change_its_character_style(self, style_set_fixture):
+        run, style, expected_xml = style_set_fixture
+        run.style = style
+        assert run._r.xml == expected_xml
+
     def it_can_add_text(self, add_text_fixture):
         run, text_str, expected_xml, Text_ = add_text_fixture
         _text = run.add_text(text_str)
@@ -306,14 +323,26 @@ class DescribeRun(object):
         expected_xml = an_r().with_nsdecls().with_child(rPr_bldr).xml()
         return run, bool_prop_name, value, expected_xml
 
-    @pytest.fixture
-    def run(self):
-        r = an_r().with_nsdecls().element
-        return Run(r)
+    @pytest.fixture(params=['Foobar', None])
+    def style_get_fixture(self, request):
+        style = request.param
+        r = self.r_bldr_with_style(style).element
+        run = Run(r)
+        return run, style
 
-    @pytest.fixture
-    def Text_(self, request):
-        return class_mock(request, 'docx.text.Text')
+    @pytest.fixture(params=[
+        (None, None),
+        (None, 'Foobar'),
+        ('Foobar', None),
+        ('Foobar', 'Foobar'),
+        ('Foobar', 'Barfoo'),
+    ])
+    def style_set_fixture(self, request):
+        before_style, after_style = request.param
+        r = self.r_bldr_with_style(before_style).element
+        run = Run(r)
+        expected_xml = self.r_bldr_with_style(after_style).xml()
+        return run, after_style, expected_xml
 
     @pytest.fixture
     def text_prop_fixture(self, Text_):
@@ -324,3 +353,21 @@ class DescribeRun(object):
         ).element
         run = Run(r)
         return run, 'foobar'
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def run(self):
+        r = an_r().with_nsdecls().element
+        return Run(r)
+
+    def r_bldr_with_style(self, style):
+        rPr_bldr = an_rPr()
+        if style is not None:
+            rPr_bldr.with_child(an_rStyle().with_val(style))
+        r_bldr = an_r().with_nsdecls().with_child(rPr_bldr)
+        return r_bldr
+
+    @pytest.fixture
+    def Text_(self, request):
+        return class_mock(request, 'docx.text.Text')
